@@ -3,9 +3,9 @@ package Number::ZipCode::JP::Table::Company;
 use strict;
 use warnings;
 
-our $VERSION = '0.20110930';
+our $VERSION = '0.20111031';
 
-# Table last modified: 2011-09-30
+# Table last modified: 2011-10-31
 our %ZIP_TABLE = (
     '001' => '(?:8(?:5(?:[02]1|88)|612))',
     '002' => '(?:850[1-4])',
@@ -34,7 +34,7 @@ our %ZIP_TABLE = (
     '027' => '(?:(?:850[1-3]|0595))',
     '028' => '(?:(?:8(?:0(?:4[02]|3[01])|392|696)|7(?:39[2-6]|[15]92|995)|4(?:39[358]|19[35])|(?:0[135]|1[13])92|6(?:19[23568]|892)|3(?:69[247]|392)|5495))',
     '029' => '(?:(?:4(?:19[245]|29[23]|59[23])|2(?:29[23]|396)|(?:01|56)92))',
-    '030' => '(?:(?:8(?:5(?:3[03]|7[047]|[14][0135]|0[35]|6[067]|2[0-4]|8[05]|5[02-68])|6(?:04|22|33|49|55|77|86|6[78]|1[01]))|01(?:9[26]|8[013-68])|1(?:49[26]|393|798)))',
+    '030' => '(?:(?:8(?:5(?:3[03]|7[047]|5[02-58]|[14][0135]|0[35]|6[067]|2[0-4]|8[05])|6(?:04|22|33|49|55|77|86|6[78]|1[01]))|01(?:9[26]|8[013-68])|1(?:49[26]|393|798)))',
     '031' => '(?:8(?:5(?:20|4[3-5]|3[38]|5[0158]|7[07]|8[58]|0[1457]|1[01])|6(?:55|86|1[127]|0[18])))',
     '033' => '(?:86(?:04|66|88))',
     '034' => '(?:(?:8(?:6(?:05|28|1[358])|5(?:65|78))|039[238]))',
@@ -63,7 +63,7 @@ our %ZIP_TABLE = (
     '057' => '(?:85(?:11|58))',
     '058' => '(?:(?:0292|8501))',
     '059' => '(?:(?:1(?:39[2-6]|59[2-6]|69[23]|292)|0(?:59[2568]|99[3578]|49[236])|2(?:[14]92|598)|8[67]01|3195))',
-    '060' => '(?:8(?:5(?:7[02-46-9]|[458]\d|[12][0-79]|0[1-35689]|3[0-36-9]|6[013568])|6(?:[12]\d|5[14-68]|7[016-8]|6[16-8]|0[1-57-9]|4[0-46-9]|3[013-9])|7(?:11|67|2[015]|9[25-7]|0[35-7])))',
+    '060' => '(?:8(?:5(?:7[02-46-9]|[458]\d|[12][0-79]|0[1-35689]|3[0-36-9]|6[013568])|6(?:[12]\d|5[14-68]|7[016-8]|6[16-8]|3[014-9]|0[1-57-9]|4[0-46-9])|7(?:11|67|2[015]|9[25-7]|0[35-7])))',
     '061' => '(?:(?:1(?:49[236-8]|19[2356]|39[2356])|0(?:29[2356]|59[25]|692)|3(?:29[2-6]|197|692)|2292))',
     '062' => '(?:8(?:6(?:55|86|0[1-357-9]|3[0135]|2[24]|4[12]|1[0278]|6[68])|5(?:01|20|7[025]|1[013467]|5[58]|3[029])))',
     '063' => '(?:8(?:5(?:58|0[17]|[18][05])|6(?:41|0[1-36-8]|1[12])))',
@@ -104,13 +104,13 @@ our %ZIP_TABLE = (
     '098' => '(?:(?:5(?:[78]92|298|595)|(?:28|62|0[13])92|1(?:69[23]|792)|339[23568]))',
     '099' => '(?:(?:2(?:19[2-8]|49[235]|392)|1(?:49[2568]|19[78]|595)|3(?:29[23]|69[78])|4(?:19[256]|492)|(?:56|65)92|049[245]))',
     '100' => '(?:(?:8(?:9(?:4[015]|8[0-35-79]|6[0-25-9]|7[0-2457-9]|2[0-24-79]|9[46]|3[0137]|1[02-9]|0[1-579]|5[0-3569])|1(?:3[01589]|6\d|0[2358]|4[0149]|5[016-8]|8[0-26-9]|7[1-37]|1[01357-9]|2[0-3568])|6(?:55|86|2[019]|1[057]|3[0-29]|7[067]|6[3568]|0[268]|4[049])|3(?:66|70|5[015]|0[2378]|4[158]|2[1245]|3[138]|1[01]|8[038])|2(?:46|70|6[02578]|2[78]|8[2358]|0[13]|1[014-69]|3[2-4])|5(?:11|4[03]|5[058]|2[02]|6[07]|8[58]|7[57]|0[35-7])|4(?:02|56|1[015]|2[0147]|3[09]|4[048]|8[48])|0(?:19|66|7[07-9]|8[68]|5[01])|79[158])|6(?:1(?:62|7[0-578]|5[0-2])|2(?:55|77|6[02])|0(?:66|80)|75[1-6])|149[28]|3131))',
-    '101' => '(?:8(?:3(?:3[135]|0[1257-9]|8[01358]|6[02356]|7[0158]|5[0-689]|2[1-8]|1[013-7]|4[56])|5(?:6[0-2568]|5[289]|4[2-5]|8[1568]|7[6-9]|0[1-46-9]|3[0-5]|1[0-24-69]|2[0-3568])|4(?:7[05-7]|8[13]|0[57-9]|3[0379]|4[13-9]|6[04-9]|5[0-46-9]|2[125]|1[0-25689])|6(?:8[28]|0[5-79]|6[2578]|3[0346-8]|5[14-6]|4[1-3568]|1[0-479]|7[026]|2[0-24-9])|9(?:[019]1|35|50|7[0-37]|4[16]|8[036])|7(?:0[137]|1[0-25-8])|0(?:11|50|77|0[12])|20[1-4]|101))',
+    '101' => '(?:8(?:3(?:3[135]|0[1257-9]|8[01358]|6[02356]|7[0158]|5[0-689]|2[1-8]|1[013-7]|4[56])|5(?:6[0-2568]|5[289]|4[2-5]|8[1568]|7[6-9]|0[1-46-9]|3[0-5]|1[0-24-69]|2[0-3568])|4(?:7[05-7]|8[13]|0[57-9]|3[0379]|4[13-9]|6[04-9]|5[0-46-9]|2[125]|1[0-25689])|6(?:8[28]|0[5-79]|1[0-379]|6[2578]|3[0346-8]|5[14-6]|4[1-3568]|7[026]|2[0-24-9])|9(?:[019]1|35|50|7[0-37]|4[16]|8[036])|7(?:0[137]|1[0-25-8])|0(?:11|50|77|0[12])|20[1-4]|101))',
     '102' => '(?:8(?:4(?:5[0-2569]|8[13489]|6[0-24-68]|4[057]|2[014679]|0[125-7]|1[014579]|7[0478]|3[0-3578])|1(?:1[0-278]|5[0-25]|3[0-289]|7[0-25-8]|8[0-24-8]|2[02358]|0[1-359]|4[0-24]|6[016])|6(?:3[0-3579]|4[245]|2[016-8]|8[0589]|7[17-9]|0[1-479]|1[0-47-9]|5[016]|6[06-8])|5(?:5[024-9]|2[0289]|6[079]|3[0139]|4[013]|8[0458]|1[01568]|7[013578]|0[2-68])|3(?:4[19]|1[0134]|3[1-356]|8[1-38]|7[0237]|5[035-7]|6[248]|0[1-359]|2[0-24])|2(?:88|5[015]|1[158]|7[257]|2[2568]|3[0-2468]|0[15]|6[0245]|4[016])|0(?:08|77|8[0-35]|1[125689])|79[58]))',
-    '103' => '(?:8(?:2(?:0[1-6]|1[0-2478]|3[0-35-9]|6[0135]|4[0-35-8]|7[02358]|8[457]|2[124589]|5[0-25689])|4(?:7[0-3]|2[2-7]|0[1-57]|6[0-256]|3[0-57-9]|1[0-79]|8[01467]|5[016]|4[3489])|5(?:0[1-367]|4[2358]|8[4-689]|[12][0-25]|5[24-68]|3[013-8]|6[067]|7[0157])|3(?:7[03]|5[0-2458]|0[136-8]|8[0348]|2[01348]|4[15-7]|1[0137]|6[036]|3[01357-9])|6(?:7[05-7]|6[0568]|3[0-269]|8[0469]|5[0-36]|4[014])|0[01]1))',
-    '104' => '(?:(?:8(?:1(?:2[2-589]|3[0-58]|0[124-689]|5[158]|8[0139]|1[124-8]|4[25]|6[1-8]|7[0-25-8])|4(?:1[01589]|2[0-2459]|4[03-578]|8[168]|0[1-8]|[67][068]|5[0156]|3[013-68])|5(?:1[028]|4[0468]|3[03589]|5[0134689]|7[02]|2[0138]|6[036-8]|0[1256]|8[014578])|3(?:6[015]|4[04]|1[0-3579]|2[01458]|5[167]|7[27]|3[02358]|8[038]|0[2-59])|2(?:4[03]|1[0-258]|3[38]|2[28]|0[568]|5[0-35-7]|7[07]|6[026]|8[0-24589])|6(?:50|6[0158]|8[05]|7[08])|0(?:55|77|1[01]|0[1347]))|6241))',
+    '103' => '(?:8(?:4(?:7[0-3]|2[2-7]|0[1-57]|6[0-256]|3[0-57-9]|1[0-79]|8[01467]|5[016]|4[3489])|2(?:3\d|0[1-6]|1[0-2478]|6[0135]|4[0-35-8]|7[02358]|8[457]|2[124589]|5[0-25689])|5(?:0[1-367]|4[2358]|8[4-689]|[12][0-25]|5[24-68]|3[013-8]|6[067]|7[0157])|3(?:7[03]|5[0-2458]|0[136-8]|8[0348]|2[01348]|4[15-7]|1[0137]|6[036]|3[01357-9])|6(?:7[05-7]|6[0568]|8[0469]|5[0-36]|3[1269]|4[014])|0[01]1))',
+    '104' => '(?:(?:8(?:1(?:2[2-589]|3[0-58]|0[124-689]|5[158]|8[0139]|1[124-8]|4[25]|6[1-8]|7[0-25-8])|4(?:1[01589]|3[013-689]|4[03-578]|8[168]|0[1-8]|[67][068]|5[0156]|2[0-59])|5(?:1[028]|4[0468]|3[03589]|5[0134689]|7[02]|2[0138]|6[036-8]|0[1256]|8[014578])|3(?:6[015]|4[04]|1[0-3579]|2[01458]|5[167]|7[27]|3[02358]|8[038]|0[2-59])|2(?:4[03]|1[0-258]|3[38]|2[28]|0[568]|5[0-35-7]|7[07]|6[026]|8[0-24589])|6(?:50|6[0158]|8[05]|7[08])|0(?:55|77|1[01]|0[1347]))|6241))',
     '105' => '(?:(?:8(?:4(?:3[24-79]|0[124578]|8[02-8]|1[0-24-689]|5[0-35-8]|2[0247-9]|7[0-39]|4[014-9]|6[01457])|5(?:2[0-357-9]|1[0-2578]|8[0-2457-9]|5[02-8]|0[579]|7[4-9]|4[35689]|6[0378]|3[0457])|6(?:54|6[0568]|1[01348]|4[02]|7[078]|3[014]|8[05-9]|2[1346]|0[3468])|0(?:55|0[12578]|7[07]|8[58]|1[0-2])|3(?:01|22|33|1[0-3])|7(?:0[127]|1[1267]))|7444))',
     '106' => '(?:(?:8(?:5(?:08|4[134]|6[0-35-79]|7[136-8]|3[25]|1[458]|2[12]|5[0-35689]|8[0157-9])|6(?:77|6[158]|5[25]|1[168]|0[18]|2[0256]|8[15]|3[069]|4[0-24589])|0(?:[01]1|39)|7(?:11|97)|401)|6(?:1(?:61|88)|06[06])))',
-    '107' => '(?:8(?:5(?:8[13589]|2[0-24578]|5[0-26-8]|4[356]|3[023]|0[258]|7[0579]|6[0357]|1[15])|6(?:42|8[06]|6[78]|2[023578]|1[15-79]|0[14]|7[46]|3[0-3689]|5[05])|4(?:20|34|56|77|0[134]|8[24]|6[067]|1[04679]|4[08])|3(?:55|4[028]|7[013]|3[1568]|2[0346]|8[08])|0(?:06|77)))',
+    '107' => '(?:8(?:5(?:8[13589]|2[0-24578]|5[0-26-8]|4[356]|3[023]|0[258]|7[0579]|6[0357]|1[15])|6(?:42|8[06]|6[78]|2[023578]|1[15-79]|0[14]|7[46]|3[0-3689]|5[05])|4(?:20|34|56|77|0[134]|8[24]|6[067]|1[04679]|4[08])|3(?:55|4[028]|7[013]|2[0346]|3[01568]|8[08])|0(?:06|77)))',
     '108' => '(?:(?:8(?:5(?:7[01358]|3[02369]|6[124-8]|4[03-578]|5[0-35-9]|0[1-3569]|2[035]|1[0258]|8[013568])|3(?:3[13489]|1[137]|6[0168]|0[357]|7[0-37-9]|5[0158]|8[134689]|4[15]|2[0-35689])|4(?:0[347]|8[45]|6[67]|5[16]|7[478]|2[013-5]|3[029]|1[0-24-7]|4[48])|2(?:7[05-8]|4[128]|8[02]|0[1-38]|3[0-4]|5[05]|1[01]|2[0-28])|6(?:50|1[0-2568]|4[0-2468]|0[126-8]|3[235-8]|2[0-28])|0(?:[25]0|11|8[08]|7[01]|0[15])|7(?:23|1[03]|0[1-37])|117)|63(?:50|63)))',
     '109' => '(?:8792)',
     '110' => '(?:8(?:5(?:6[0-25-7]|5[03589]|4[0134689]|0[1-357-9]|7[35-9]|3[0-79]|1[0-3578]|2[0-478]|8[02-468])|6(?:97|0[2359]|2[0-24-68]|6[0-259]|5[34]|4[245]|1[03-57-9]|3[058]|7[135-8]|8[015-8])|7(?:8[027]|5[057]|1[2-6]|0[168]|4[05]|3[36]|2[1-35])|80[78]|408))',
@@ -129,11 +129,11 @@ our %ZIP_TABLE = (
     '131' => '(?:8(?:5(?:40|65|1[0-389]|3[03]|2[0467]|8[458]|5[05]|0[13-9])|711))',
     '132' => '(?:8(?:5(?:33|85|5[015]|0[137]|6[27])|6(?:01|74|[68][68])|7(?:3[029]|1[15])))',
     '133' => '(?:8(?:5(?:[01]1|8[05]|5[238])|70[46]))',
-    '134' => '(?:8(?:6(?:22|78|86|[14][02]|0[1-39]|3[01])|5(?:[15]5|20|33|7[05-7]|8[568]|0[237])|702))',
-    '135' => '(?:8(?:5(?:3[0-35]|5\d|7[03-57-9]|8[125-7]|6[035-7]|0[1458]|4[08]|2[1-358]|1[0-478])|4(?:22|4[0358]|0[24]|7[0137]|5[18]|8[0-2]|6[014]|1[15]|3[026])|6(?:02|41|86|2[0-25]|6[168]|3[0-29]|7[0178]|5[059]|1[146-9])|3(?:50|8[3-578]|7[025]|0[13]|2[02]|6[0236]|3[01]|1[0-28])|7(?:3[0-38]|2[0-3]|0[17]|1[0178])|11[0-4]))',
-    '136' => '(?:8(?:5(?:4[03]|1[2357]|3[13]|7[057]|5[058]|6[07]|8[0189]|0[1257]|2[1-35])|6(?:[68]6|3[057]|0[357]|7[0157]|2[0267]|4[08]|1[125])|7(?:[23]3|11)|405|880|908))',
+    '134' => '(?:8(?:5(?:[15]5|20|33|7[05-7]|8[568]|0[237])|6(?:22|86|[14][02]|0[1-39]|3[01])|702))',
+    '135' => '(?:8(?:5(?:3[0-35]|5\d|7[03-57-9]|8[125-7]|0[1458]|4[08]|2[1-358]|1[0-478]|6[035-8])|4(?:22|4[0358]|0[24]|7[0137]|5[18]|8[0-2]|6[014]|1[15]|3[026])|6(?:02|41|86|2[0-25]|6[168]|3[0-29]|7[0178]|5[059]|1[146-9])|3(?:50|8[3-578]|7[025]|0[13]|2[02]|6[0236]|3[01]|1[0-28])|7(?:3[0-38]|2[0-3]|0[17]|1[0178])|11[0-4]|080))',
+    '136' => '(?:8(?:5(?:4[03]|1[2357]|3[13]|7[057]|6[07]|5[05]|8[0189]|0[1257]|2[1-35])|6(?:[68]6|3[057]|0[357]|7[0157]|2[0267]|4[08]|1[125])|7(?:[23]3|11)|405|880|908))',
     '137' => '(?:8(?:6(?:23|50|86)|08[18]|581))',
-    '140' => '(?:8(?:5(?:[89]0|7[1-36]|4[0-37-9]|2[01359]|3[013689]|6[0367]|0[125-8]|5[0-28]|1[1256])|6(?:4[04]|0[17]|6[0168]|1[13-79]|7[0578]|2[13568]|8[078]|3[01479]|5[03568])|7(?:88|1[015-7]|2[12]|0[279])))',
+    '140' => '(?:8(?:5(?:[89]0|7[1-36]|4[0-37-9]|3[013689]|6[0367]|2[013569]|0[125-8]|5[0-28]|1[1256])|6(?:4[04]|0[17]|6[0168]|1[13-79]|7[0578]|2[13568]|8[078]|3[01479]|5[03568])|7(?:88|1[015-7]|2[12]|0[279])))',
     '141' => '(?:8(?:6(?:3[0137-9]|2[01389]|4[0-36-8]|0[2-6]|7[0-36]|1[01568]|8[0136-8]|5[035-8]|6[024-68])|5(?:2[0-2569]|0[13-578]|4[045]|1[024579]|3[03-5]|5[05-79]|6[015-8]|7[1256]|8[02-68])|4(?:2[0-3]|1[1-9])|7(?:0[127]|1[05])|001))',
     '142' => '(?:8(?:5(?:[01]1|22|33|40|67|5[058]|8[58])|6(?:11|39|66)))',
     '143' => '(?:(?:85(?:28|70|3[13589]|8[05]|6[04578]|0[4-8]|4[014]|5[0258]|1[145])|6501))',
@@ -160,7 +160,7 @@ our %ZIP_TABLE = (
     '168' => '(?:8(?:5(?:[67]0|85|3[03]|5[058]|0[1-468]|2[05]|1[0-2])|6(?:01|26|[18][16])|081))',
     '169' => '(?:8(?:5(?:6[018]|2[0-25-7]|8[0568]|4[013]|7[07]|3[0135]|0[37-9]|1[015-7]|5[01568])|6(?:2[04]|5[056]|7[78]|0[1358]|1[0-36]|6[1468]|4[0458]|3[179])|0(?:50|77|1[12])|7(?:[01]1|22)|915))',
     '170' => '(?:(?:8(?:4(?:1[015-79]|4[0-2478]|0[124-69]|7[067]|5[015-9]|6[0156]|2[0-467]|8[08]|3[02-468])|6(?:[68]6|12|53|0[25]|3[35])|5(?:51|85)|073)|6080))',
-    '171' => '(?:85(?:8[26]|5[02578]|7[027]|4[045]|3[159]|2[0-35-8]|1[0-2468]|6[0189]|0[1-37-9]))',
+    '171' => '(?:85(?:8[26]|5[02578]|3[19]|7[027]|4[045]|2[0-35-8]|1[0-2468]|6[0189]|0[1-37-9]))',
     '173' => '(?:8(?:5(?:[06]1|30|4[03]|1[0-25-9]|8[058]|5[258])|6(?:48|66|3[29]|1[01]|0[1256])|710))',
     '174' => '(?:8(?:5(?:30|88|5[058]|6[07]|2[0146]|0[15])|6(?:01|12|46|3[369]|8[068])|7(?:[01]1|3[079]|4[0134])|860|903))',
     '175' => '(?:85(?:88|7[17]))',
@@ -317,7 +317,7 @@ our %ZIP_TABLE = (
     '341' => '(?:85(?:01|5[058]|2[67]))',
     '342' => '(?:8(?:50[125]|601))',
     '343' => '(?:(?:8(?:5(?:11|40|85|5[45]|0[12])|601)|019[23]))',
-    '344' => '(?:8(?:5(?:11|40|55|66|77|3[35]|8[58]|2[12]|0[68])|686))',
+    '344' => '(?:8(?:5(?:[06]6|11|40|55|7[78]|3[35]|8[58]|2[12])|686))',
     '345' => '(?:850[1248])',
     '346' => '(?:(?:8(?:5(?:[34]0|24|0[16])|68[56])|019[2-68]))',
     '347' => '(?:(?:85(?:67|85|0[1-4]|1[03]|5[05])|019[25]))',
@@ -566,7 +566,7 @@ our %ZIP_TABLE = (
     '598' => '(?:85(?:[13]1|22|6[06]|0[38]|5[05]))',
     '599' => '(?:(?:0[23]92|8531))',
     '600' => '(?:8(?:5(?:[347]0|1[019]|5[058]|8[1568]|6[67]|0[1-35])|6(?:52|77|86|6[56])|7(?:11|87)))',
-    '601' => '(?:(?:85(?:01|50|3[03]|8[58]|1[01])|0(?:292|797)|1(?:192|495)))',
+    '601' => '(?:(?:85(?:01|42|50|3[03]|8[58]|1[01])|0(?:292|797)|1(?:192|495)))',
     '602' => '(?:8(?:5(?:[01]1|55|66|70|8[058]|2[05])|611))',
     '603' => '(?:85(?:11|22|55|77))',
     '604' => '(?:8(?:5(?:20|8[058]|7[178]|6[07]|5[01568]|1[01]|0[1-358])|666|798))',
@@ -641,14 +641,14 @@ our %ZIP_TABLE = (
     '677' => '(?:851[01])',
     '678' => '(?:(?:1(?:29[257]|19[58])|0(?:19[235]|292)|85(?:43|85)))',
     '679' => '(?:(?:2(?:2(?:9[25]|8[0-589])|392|493)|5(?:3(?:92|8[0-3])|19[28]|292|595)|0(?:1(?:98|8[0178])|29[25])|4(?:19[235]|39[235]|298)|1[12]92|339[23]))',
-    '680' => '(?:(?:8(?:5(?:33|41|6[06]|7[0-257]|2[02]|8[58]|0[12]|5[0-5]|1[017])|6(?:[01]1|[34]4|22|66|78|8[68])|701)|0(?:49[235]|197|792)|1192))',
+    '680' => '(?:(?:8(?:5(?:33|41|6[06]|7[0-2578]|2[02]|8[58]|0[12]|5[0-5]|1[017])|6(?:[01]1|[34]4|22|66|78|8[68])|701)|0(?:49[235]|197|792)|1192))',
     '681' => '(?:8501)',
     '682' => '(?:(?:8(?:5(?:[58]5|22|0[15])|6[01]1)|0(?:19[2357]|498)))',
     '683' => '(?:8(?:5(?:20|1[0-2568]|0[1-68])|6(?:70|86|0[1-5])))',
     '684' => '(?:8(?:5(?:[01]1|[58]5)|6(?:01|86)))',
     '685' => '(?:8(?:5(?:[58]5|12)|6(?:01|66)))',
     '689' => '(?:(?:2(?:29[2358]|39[235])|(?:[45]2|3[45])92|059[25]|119[23]))',
-    '690' => '(?:(?:8(?:5(?:40|77|5[0-2568]|1[0235-9]|6[07]|0[1-57-9]|8[08]|3[0159]|2[0-3568])|6(?:[01]1|7[07]|6[068]|8[68]))|039[36]|219[28]|1492))',
+    '690' => '(?:(?:8(?:5(?:40|77|5[0-2568]|1[0235-9]|3[01569]|6[07]|0[1-57-9]|8[08]|2[0-3568])|6(?:[01]1|7[07]|6[068]|8[68]))|039[36]|219[28]|1492))',
     '691' => '(?:860[12])',
     '692' => '(?:8(?:5(?:[15]0|06)|6(?:01|86)))',
     '693' => '(?:8(?:5(?:01|23|66|3[013]|5[05]|8[57]|1[01])|6(?:01|14|86)))',
@@ -716,7 +716,7 @@ our %ZIP_TABLE = (
     '757' => '(?:(?:8(?:5(?:11|85)|6(?:34|86))|029[28]))',
     '758' => '(?:8(?:6(?:15|86|4[58])|5(?:[58]5|70)))',
     '759' => '(?:(?:(?:22|55)92|029[2357]|419[2468]|659[25]))',
-    '760' => '(?:8(?:5(?:1\d|0[1-578]|5[0-2457-9]|[36][0-246-9]|4[4-7]|2[0-3578]|8[0-8]|7[0-69])|6(?:71|6[0178]|3[04689]|5[05]|[14][48]|2[013-6]|8[06-8]|0[13478])))',
+    '760' => '(?:8(?:5(?:1\d|0[1-578]|5[0-2457-9]|[36][0-246-9]|2[0-578]|4[4-7]|8[0-8]|7[0-69])|6(?:71|6[0178]|3[04689]|5[05]|[14][48]|2[013-6]|8[06-8]|0[13478])))',
     '761' => '(?:(?:0(?:1(?:8[5-9]|9[2-8])|39[3-7]|79[35]|[46]92)|4(?:4(?:89|9[2-8])|3(?:88|9[235-8])|19[2-5])|8(?:5(?:[014]1|33|77|8[25689]|6[67]|5[58])|601)|1(?:79[2-5]|49[2-4]|592)|2(?:39[2356]|49[23])))',
     '762' => '(?:8(?:5(?:1[015]|0[23578])|60[12]))',
     '763' => '(?:8(?:5(?:1[0-268]|0[1-478])|60[358]))',
@@ -860,7 +860,7 @@ our %ZIP_TABLE = (
     '901' => '(?:(?:2(?:5(?:40|88|97|6[0679]|0[1268]|1[0-25]|5[0-35-9]|3[014]|2[0156])|6(?:86|0[127]|1[01])|7(?:01|10|33)|49[2356]|39[25])|0(?:49[2-6]|29[2-5]|19[2-4]|39[23]|592|695)|3(?:[679]92|19[23]|59[25]|496|895)|1(?:19[2356]|39[23]|[24]92|595)))',
     '902' => '(?:85(?:21|8[58]|5[05]|[17][01]))',
     '903' => '(?:(?:02(?:20|1[013-578]|0[13-7])|860[1-3]))',
-    '904' => '(?:(?:0(?:19[2-5]|39[2-5]|49[2-46]|29[35])|2(?:19[2-6]|39[2-4]|29[23])|1(?:29[2-4]|[13]92)|85(?:[01]1|85)))',
+    '904' => '(?:(?:0(?:49[2-6]|19[2-5]|39[2-5]|29[35])|2(?:19[2-6]|39[2-4]|29[23])|1(?:29[2-4]|[13]92)|85(?:[01]1|85)))',
     '905' => '(?:(?:0(?:59[2-6]|79[2-6]|[24]92|695)|8(?:5(?:01|12|40|85)|6(?:11|68))|1(?:[23]92|495)|2192))',
     '906' => '(?:(?:0[256]92|8[56]01))',
     '907' => '(?:(?:850[1-3]|1[28]92))',
@@ -935,7 +935,7 @@ our %ZIP_TABLE = (
     '980' => '(?:(?:8(?:4(?:66|5[2-468]|7[78]|8[014-68]|4[023578]|2[0369]|1[0145]|3[013569]|0[1-358])|5(?:1[015]|4[3-6]|8[01358]|5[05]|3[13-5]|7[01457-9]|6[0156]|0[15]|2[069])|6(?:40|5[0-26]|6[018]|0[1258]|3[1-36-8]|2[12]|8[56]|7[017])|7(?:0[17]|9[2-578]))|6(?:0(?:55|88)|180)))',
     '981' => '(?:(?:3(?:6(?:8[0-24-68]|9[237])|2(?:9[23568]|8[078])|1(?:9[2-5]|8[089])|49[4-7]|[35]92)|85(?:33|85|6[03]|7[07]|2[235]|5[0-25-8]|1[01]|4[035]|0[125])|1(?:5(?:8[1-3]|9[2356])|29[2-58])|4(?:29[2-4]|392)|2192))',
     '982' => '(?:8(?:5(?:[03]1|44|66|77|2[13]|8[58]|5[15]|1[01])|601|798))',
-    '983' => '(?:8(?:5(?:70|2[0238]|3[357]|8[45]|5[156]|4[03-5]|6[05]|1[0237]|0[124679])|6(?:22|39|0[12])))',
+    '983' => '(?:8(?:5(?:70|3[357]|8[45]|5[156]|4[03-5]|6[05]|1[0237]|2[02378]|0[124679])|6(?:22|39|0[12])))',
     '984' => '(?:8(?:5(?:8[045]|7[057]|6[0178]|3[3589]|5[0-3578]|4[035]|2[125]|1[0-25689]|0[1-35])|6(?:42|54|7[056]|0[13]|8[068]|6[689])))',
     '985' => '(?:8(?:5(?:[15][015]|4[03]|2[0-2]|3[1-358]|0[12467])|6(?:55|0[17])))',
     '986' => '(?:(?:85(?:40|55|0[17]|2[25]|8[05])|0(?:195|792)|229[23]))',
